summaryrefslogtreecommitdiffstats
path: root/ash/screenshot_delegate.h
diff options
context:
space:
mode:
Diffstat (limited to 'ash/screenshot_delegate.h')
-rw-r--r--ash/screenshot_delegate.h7
1 files changed, 3 insertions, 4 deletions
diff --git a/ash/screenshot_delegate.h b/ash/screenshot_delegate.h
index fe194e8..9e7af06 100644
--- a/ash/screenshot_delegate.h
+++ b/ash/screenshot_delegate.h
@@ -20,10 +20,9 @@ class ScreenshotDelegate {
public:
virtual ~ScreenshotDelegate() {}
- // The actual task of taking a screenshot for the given window.
- // This method is called when the user wants to take a screenshot
- // manually.
- virtual void HandleTakeScreenshot(aura::Window* window) = 0;
+ // The actual task of taking a screenshot for each root window.
+ // This method is called when the user wants to take a screenshot manually.
+ virtual void HandleTakeScreenshotForAllRootWindows() = 0;
// The actual task of taking a partial screenshot for the given
// window.